@@ -3,7 +3,7 @@ from .anthology_search import anthology_search
 from .arxiv_download import arxiv_download
 from .hf_datasets_search import hf_datasets_search
 from .s2_citations import s2_get_references, s2_get_citations
-from .document_qa import create_document_qa_func
+from .document_qa import document_qa
 from .md_to_pdf import md_to_pdf
 from .web_search import web_search, tavily_web_search, exa_web_search, brave_web_search
 from .visit_webpage import visit_webpage
@@ -16,7 +16,7 @@ __all__ = [
     "s2_get_references",
     "s2_get_citations",
     "hf_datasets_search",
-    "create_document_qa_func",
+    "document_qa",
     "md_to_pdf",
     "web_search",
     "tavily_web_search",
